@@ -53,12 +53,13 @@ read_spar_sdat <- function(fname, extra) {
   cols <- as.numeric(paras$V2[which(paras$V1 == "dim2_pnts")])
   rows <- as.numeric(paras$V2[which(paras$V1 == "dim3_pnts")])
   slices <- as.numeric(paras$V2[which(paras$V1 == "nr_of_slices_for_multislice")])
+  avs <- as.integer(paras$V2[which(paras$V1 == "averages")])
+  
   #cols <- as.numeric(paras$V2[which(paras$V1 == "SUN_dim2_pnts")])
   #rows <- as.numeric(paras$V2[which(paras$V1 == "SUN_dim3_pnts")])
   
   # May be useful...
   # slices <- as.numeric(paras$V2[which(paras$V1 == "nr_of_slices_for_multislice")])
-  # avs <- as.integer(paras$V2[which(paras$V1 == "averages")])
   # dim1_pts <- as.numeric(paras$V2[which(paras$V1 == "dim1_pnts")])
   # dim1_pts <- as.numeric(paras$V2[which(paras$V1 == "SUN_dim1_pnts")])
   # nuc <- as.numeric(paras$V2[which(paras$V1 == "nucleus")])
@@ -110,7 +111,7 @@ read_spar_sdat <- function(fname, extra) {
   data <- array(data_vec,dim = c(N, cols, rows, slices, dyns, 1, 1)) 
   data <- aperm(data,c(6, 2, 3, 4, 5, 7, 1))
   
-  res <- c(NA, row_dim, col_dim, slice_dim, 1, NA, 1 / fs)
+  res <- c(NA, row_dim, col_dim, slice_dim, tr, NA, 1 / fs)
   ref <- def_ref()
   
   # TODO get from the data file
@@ -120,8 +121,8 @@ read_spar_sdat <- function(fname, extra) {
   freq_domain <- rep(FALSE, 7)
   
   meta <- list(EchoTime = te,
-               RepetitionTime = tr,
-               Manufacturer = "Philips")
+               Manufacturer = "Philips",
+               NumberOfTransients = dyns * avs)
   
   mrs_data <- mrs_data(data = data, ft = ft, resolution = res, ref = ref,
                        nuc = nuc, freq_domain = freq_domain, affine = NULL,
